@@ -140,13 +140,19 @@ html_box_accessible_initialize (AtkObject *obj, gpointer data)
 		}
 		/*
 		 * Set the parent for a Box in HtmlBoxInline to be its parent
-		 * allow for more than one HtmlBoxInLine in the hierarchy
+		 * allow for more than one HtmlBoxInLine in the hierarchy.
+		 * Do this only if HtmlBoxInLine has only one child.
 		 */
 		else if (HTML_IS_BOX_INLINE (box->parent)) {
-			parent = box->parent->parent;
+			if (box->next == NULL) {
+				parent = box->parent;
 
-			while (HTML_IS_BOX_INLINE (parent))
-				parent = parent->parent;
+				while (HTML_IS_BOX_INLINE (parent) &&
+				       parent->children->next == NULL)
+					parent = parent->parent;
+			} else
+				parent = box->parent;
+			
 		 } else
 			parent = box->parent;
 		data = g_object_get_data (G_OBJECT (parent), "view");
@@ -217,7 +223,9 @@ html_box_accessible_ref_child (AtkObject *obj, gint i)
 
 		while (child) {
 			if (n_children == i) {
-				while (HTML_IS_BOX_INLINE (child))
+				while (HTML_IS_BOX_INLINE (child) && 
+				       child->children &&
+				       child->children->next == NULL)
 					child = child->children;	
 				if (!child)
 					return NULL;
@@ -263,7 +271,8 @@ html_box_accessible_get_index_in_parent (AtkObject *obj)
 		g_assert_not_reached ();
 		return -1;
 	}
-	while (HTML_IS_BOX_INLINE (box->parent))
+	while (HTML_IS_BOX_INLINE (box->parent) && 
+	       box->parent->children->next == NULL)
 		box = box->parent;
 
 	if (HTML_IS_BOX_TABLE_CELL (box)) {
@@ -321,7 +330,7 @@ html_box_accessible_get_parent (AtkObject *obj)
 			g_return_val_if_fail (!box->parent, NULL); 
 			g_return_val_if_fail (widget, NULL); 
 			parent = gtk_widget_get_accessible (widget);
-			obj->accessible_parent = parent;
+			atk_object_set_parent (obj, parent);
 		}
 	}
 	return parent;
