@@ -218,6 +218,8 @@ html_box_block_link_accessible_get_link (AtkHypertext *hypertext,
 	gboolean found;
 	HtmlLinkAccessible *link;
 	AtkHyperlink *hyperlink;
+	HtmlBox *parent;
+	gpointer data;
 
 	atk_gobj = ATK_GOBJECT_ACCESSIBLE (hypertext);
 	g_obj = atk_gobject_accessible_get_object (atk_gobj);
@@ -241,6 +243,12 @@ html_box_block_link_accessible_get_link (AtkHypertext *hypertext,
 				   (GWeakNotify) box_link_destroyed,
 				   hyperlink);
 		g_object_set_data (G_OBJECT (box_link), link_hyperlink, hyperlink);
+		/* Store HtmlView on box_link */
+		parent = box_link->parent;
+		data = g_object_get_data (G_OBJECT (parent), "view");
+		if (data)
+			g_object_set_data (G_OBJECT (box_link), "view", data);
+
 	}
 	return hyperlink;
 }
