@@ -51,7 +51,6 @@
 #include "a11y/htmlboxembeddedaccessible.h"
 #include "a11y/htmlboxaccessible.h"
 #include "a11y/htmlboxtableaccessible.h"
-#include "a11y/htmlboxtextaccessible.h"
 #endif
 
 enum {
@@ -82,7 +81,6 @@ HTML_ACCESSIBLE_FACTORY (HTML_TYPE_BOX_BLOCK_ACCESSIBLE, html_box_block_accessib
 HTML_ACCESSIBLE_FACTORY (HTML_TYPE_BOX_EMBEDDED_ACCESSIBLE, html_box_embedded_accessible)
 HTML_ACCESSIBLE_FACTORY (HTML_TYPE_BOX_ACCESSIBLE, html_box_accessible)
 HTML_ACCESSIBLE_FACTORY (HTML_TYPE_BOX_TABLE_ACCESSIBLE, html_box_table_accessible)
-HTML_ACCESSIBLE_FACTORY (HTML_TYPE_BOX_TEXT_ACCESSIBLE, html_box_text_accessible)
 #endif
 
 
@@ -215,11 +213,11 @@ html_view_relayout (HtmlView *view)
 			html_view_try_jump (view);
 	}
 	if (view->relayout_timeout_id != 0) {
-		gtk_timeout_remove (view->relayout_timeout_id);
+		g_source_remove (view->relayout_timeout_id);
 		view->relayout_timeout_id = 0;
 	}
 	if (view->relayout_idle_id != 0) {
-		gtk_idle_remove (view->relayout_idle_id);
+		g_source_remove (view->relayout_idle_id);
 		view->relayout_idle_id = 0;
 	}
 
@@ -242,7 +240,7 @@ relayout_timeout_callback (gpointer data)
 	view->relayout_timeout_id = 0;
 
 	if (view->relayout_idle_id != 0) {
-		gtk_idle_remove (view->relayout_idle_id);
+		g_source_remove (view->relayout_idle_id);
 		view->relayout_idle_id = 0;
 	}
         return FALSE;
@@ -259,7 +257,7 @@ relayout_idle_callback (gpointer data)
 	view->relayout_idle_id = 0;
 
 	if (view->relayout_timeout_id != 0) {
-		gtk_timeout_remove (view->relayout_timeout_id);
+		g_source_remove (view->relayout_timeout_id);
 		view->relayout_timeout_id = 0;
 	}
         return FALSE;
@@ -269,14 +267,14 @@ static void
 html_view_relayout_when_idle (HtmlView *view)
 {
 	if (view->relayout_idle_id == 0)
-		view->relayout_idle_id = gtk_idle_add (relayout_idle_callback, view);
+		view->relayout_idle_id = g_idle_add (relayout_idle_callback, view);
 }
 
 static void
 html_view_relayout_after_timeout (HtmlView *view)
 {
 	if (view->relayout_timeout_id == 0)
-		view->relayout_timeout_id = gtk_timeout_add (RELAYOUT_TIMEOUT_INTERVAL, relayout_timeout_callback, view);
+		view->relayout_timeout_id = g_timeout_add (RELAYOUT_TIMEOUT_INTERVAL, relayout_timeout_callback, view);
 }
 
 static void
@@ -820,12 +818,12 @@ html_view_destroy (GtkObject *object)
 	gpointer saved_focus;
 
 	if (view->relayout_timeout_id != 0) {
-		gtk_timeout_remove (view->relayout_timeout_id);
+		g_source_remove (view->relayout_timeout_id);
 		view->relayout_timeout_id = 0;
 	}
 
 	if (view->relayout_idle_id != 0) {
-		gtk_idle_remove (view->relayout_idle_id);
+		g_source_remove (view->relayout_idle_id);
 		view->relayout_idle_id = 0;
 	}
 
@@ -1474,7 +1472,6 @@ html_view_get_accessible (GtkWidget *widget)
 			HTML_ACCESSIBLE_SET_FACTORY (HTML_TYPE_BOX_EMBEDDED, html_box_embedded_accessible);
 			HTML_ACCESSIBLE_SET_FACTORY (HTML_TYPE_BOX, html_box_accessible);
 			HTML_ACCESSIBLE_SET_FACTORY (HTML_TYPE_BOX_TABLE, html_box_table_accessible);
-			HTML_ACCESSIBLE_SET_FACTORY (HTML_TYPE_BOX_TEXT, html_box_text_accessible);
 		}
 		first_time = FALSE;
 	}
